@@ -180,7 +180,7 @@ static void curse_artifact(object_type * o_ptr)
 
 static void random_plus(object_type * o_ptr)
 {
-	int this_type = (o_ptr->tval < TV_BOOTS ? 23 : 19);
+	int this_type = (o_ptr->tval < TV_BOOTS ? 24 : 20);
 
 	switch (artifact_bias)
 	{
@@ -367,10 +367,15 @@ static void random_plus(object_type * o_ptr)
 		if (!artifact_bias && randint1(11) == 1)
 			artifact_bias = BIAS_ROGUE;
 		break;
-	case 20: case 21:
+	case 20:
+		o_ptr->art_flags1 |= TR1_MAGIC_MASTERY;
+		if (!artifact_bias && randint1(11) == 1)
+			artifact_bias = BIAS_MAGE;
+		break;
+	case 21: case 22:
 		o_ptr->art_flags1 |= TR1_TUNNEL;
 		break;
-	case 22: case 23:
+	case 23: case 24:
 		if (o_ptr->tval == TV_BOW) random_plus(o_ptr);
 		else
 		{
@@ -1642,6 +1647,20 @@ bool create_artifact(object_type *o_ptr, bool a_scroll)
 		}
 	};
 
+	/* Some Artifact Weapon gets extra dice */
+	if (o_ptr->tval < TV_BOOTS)
+	{
+		if (!a_cursed) {
+			if (one_in_(2 + (o_ptr->dd / 2))) o_ptr->dd++;
+		}
+
+		/* Hack -- Super-charge the damage dice */
+		while (one_in_(10L * o_ptr->dd)) o_ptr->dd++;
+
+		/* Hack -- Lower the damage dice */
+		if (o_ptr->dd > 9) o_ptr->dd = 9;
+	}
+
 	if (has_pval)
 	{
 		if (o_ptr->art_flags1 & (TR1_BLOWS))
@@ -2920,10 +2939,11 @@ void create_named_ego(object_type *o_ptr)
 {
 	int max_type = (o_ptr->tval < TV_BOOTS ? 7 : 5);
 	char buf[80];
-	bool has_pval = FALSE;
+	bool got_random_plus;
 	bool has_blows;
 	bool has_act;
 	u32b o1, o2, o3;
+	u32b f1, f2, f3;
 
 	/* Paranoia */
 	if (o_ptr->tval <= TV_CORPSE || o_ptr->tval >= TV_LITE) return;
@@ -2931,9 +2951,6 @@ void create_named_ego(object_type *o_ptr)
 	/* Prevent Ammo */
 	if (o_ptr->tval <= TV_BOLT && o_ptr->tval >= TV_SHOT) return;
 
-	/* Do not use bias */
-	artifact_bias = 0;
-
 	/* Save old flags */
 	object_flags(o_ptr, &o1, &o2, &o3);
 
@@ -2944,16 +2961,19 @@ void create_named_ego(object_type *o_ptr)
 	has_act = (o3 & (TR3_ACTIVATE)) ? TRUE : FALSE;
 
 	/* Add one extra power */
-	while(1)
+	do
 	{
-		u32b f1, f2, f3;
+		/* Do not use bias */
+		artifact_bias = 0;
+
+		got_random_plus = FALSE;
 
 		/* Get one random power */
 		switch (randint1(max_type))
 		{
 			case 1: case 2:
 				random_plus(o_ptr);
-				has_pval = TRUE;
+				got_random_plus = TRUE;
 				break;
 			case 3: case 4:
 				random_resistance(o_ptr, FALSE);
@@ -2972,15 +2992,16 @@ void create_named_ego(object_type *o_ptr)
 #endif
 		}
 
-		/* Check extra power is added truely */
 		object_flags(o_ptr, &f1, &f2, &f3);
-		if ((o1 != f1) || (o2 != f2) || (o3 != f3)) break;
 	}
+	/* Check extra power is added truely */
+	while ((o1 == f1) && (o2 == f2) && (o3 == f3));
 
 	/* Tweak pval */
-	if(has_pval)
+	if (got_random_plus)
 	{
-		if (!o_ptr->pval)
+		/* If don't have pval, gain some pval */
+		if (o_ptr->pval == 0)
 		{
 			o_ptr->pval = 2;
 			while (o_ptr->pval < randint1(5) || one_in_(o_ptr->pval)) o_ptr->pval++;
@@ -3013,7 +3034,7 @@ void create_named_ego(object_type *o_ptr)
 	/* Do not use bias */
 	artifact_bias = 0;
 
-	/* Get randome activation */
+	/* Get random activation */
 	if (!has_act && one_in_(7))
 	{
 		o_ptr->xtra2 = 0;
