@@ -406,7 +406,7 @@ void search(void)
 {
 	int y, x, chance;
 
-	s16b this_o_idx, next_o_idx = 0;
+	s16b this_o_idx, next_o_idx;
 
 	cave_type *c_ptr;
 
@@ -538,7 +538,7 @@ void py_pickup_aux(int o_idx)
 	o_ptr = &o_list[o_idx];
 
 #ifdef JP
-/*	object_desc(old_name, o_ptr, TRUE, 0);*/
+/*	object_desc(old_name, o_ptr, OD_NAME_ONLY);*/
 	object_desc_kosuu(kazu_str, o_ptr);
 	hirottakazu = o_ptr->number;
 #endif
@@ -549,7 +549,7 @@ void py_pickup_aux(int o_idx)
 	o_ptr = &inventory[slot];
 
 	/* Describe the object */
-	object_desc(o_name, o_ptr, TRUE, 3);
+	object_desc(o_name, o_ptr, 0);
 
 	/* Message */
 #ifdef JP
@@ -578,7 +578,7 @@ void py_pickup_aux(int o_idx)
 #else
 			msg_print("You completed your quest!");
 #endif
-
+			sound(SOUND_QUEST);
 			msg_print(NULL);
 		}
 	}
@@ -588,29 +588,6 @@ void py_pickup_aux(int o_idx)
 }
 
 
-/*
- * Automatically destroy items in this grid.
- */
-static bool is_opt_confirm_destroy(object_type *o_ptr)
-{
-	if (!destroy_items) return FALSE;
-
-	/* Known to be worthless? */
-	if (leave_worth)
-		if (object_value(o_ptr) > 0) return FALSE;
-	
-	if (leave_equip)
-		if ((o_ptr->tval >= TV_SHOT) && (o_ptr->tval <= TV_DRAG_ARMOR)) return FALSE;
-	
-	if (leave_chest)
-		if ((o_ptr->tval == TV_CHEST) && o_ptr->pval) return FALSE;
-	
-	if (o_ptr->tval == TV_GOLD) return FALSE;
-	
-	return TRUE;
-}
-
-
 /*
  * Player "wants" to pick up an object or gold.
  * Note that we ONLY handle things that can be picked up.
@@ -620,7 +597,7 @@ void carry(int pickup)
 {
 	cave_type *c_ptr = &cave[py][px];
 
-	s16b this_o_idx, next_o_idx = 0;
+	s16b this_o_idx, next_o_idx;
 
 	char o_name[MAX_NLEN];
 
@@ -640,7 +617,7 @@ void carry(int pickup)
 	handle_stuff();
 
 	/* Automatically pickup/destroy/inscribe items */
-	auto_pickup_items(c_ptr);
+	autopick_pickup_items(c_ptr);
 
 #ifdef ALLOW_EASY_FLOOR
 
@@ -672,7 +649,7 @@ void carry(int pickup)
 #endif /* ALLOW_EASY_SENSE -- TNB */
 
 		/* Describe the object */
-		object_desc(o_name, o_ptr, TRUE, 3);
+		object_desc(o_name, o_ptr, 0);
 
 		/* Acquire next object */
 		next_o_idx = o_ptr->next_o_idx;
@@ -711,7 +688,7 @@ void carry(int pickup)
 		/* Pick up objects */
 		else
 		{
-			/* Hack - some objects were handled in auto_pickup_items(). */
+			/* Hack - some objects were handled in autopick_pickup_items(). */
 			if (o_ptr->marked & OM_NOMSG)
 			{
 				/* Clear the flag. */
@@ -1331,7 +1308,7 @@ msg_print("ޤФ椤ä");
 
 static void touch_zap_player(monster_type *m_ptr)
 {
-	int aura_damage = 0;
+	int aura_damage;
 	monster_race *r_ptr = &r_info[m_ptr->r_idx];
 
 	if (r_ptr->flags2 & RF2_AURA_FIRE)
@@ -1569,13 +1546,13 @@ msg_format("%^sϺ𤷤褦", m_name);
   ΤΤġѤʤΤľɡintˤȤޤä餴
   static void monk_attack(monster_type *m_ptr, long *k, char *m_name) 
      --- henkma
- */   
+ */
 static void monk_attack(monster_type *m_ptr, int *k, char *m_name) 
 {
-	int special_effect = 0, stun_effect = 0, times = 0;
+	int special_effect = 0, stun_effect = 0, times;
 	martial_arts *ma_ptr = &ma_blows[0], *old_ptr = &ma_blows[0];
 	int resist_stun = 0;
-	
+
 	monster_race *r_ptr = &r_info[m_ptr->r_idx];
 
 #ifdef JP
@@ -1654,7 +1631,7 @@ static void monk_attack(monster_type *m_ptr, int *k, char *m_name)
 
 	{
 		if (!((r_ptr->flags1 & RF1_NEVER_MOVE) ||
-			strchr("~#{}.UjmeEv$,DdsbBFIJQSXclnw!=?", r_ptr->d_char)))
+			my_strchr("~#{}.UjmeEv$,DdsbBFIJQSXclnw!=?", r_ptr->d_char)))
 		{
 #ifdef JP
 						msg_format("%s­˴έ򤯤路", m_name);
@@ -1783,15 +1760,14 @@ static void py_attack_aux(int y, int x, int mode)
 	bool            fear = FALSE;
 	bool            mdeath = FALSE;
 
-	bool            vorpal_cut = FALSE;
+	bool            vorpal_cut;
 	int             chaos_effect = 0;
 	bool            do_quake = FALSE;
 	bool			can_drain = FALSE;
 	bool            drain_msg = TRUE;
-	int             drain_result = 0, drain_heal = 0;
+	int             drain_result = 0, drain_heal;
 	int             drain_left = MAX_VAMPIRIC_DRAIN;
 	u32b            f1, f2, f3; /* A massive hack -- life-draining weapons */
-	bool            no_extra = FALSE;
 
 
 	/* Disturb the player */
@@ -1822,8 +1798,7 @@ static void py_attack_aux(int y, int x, int mode)
 
 	/* Disturb the monster */
 	m_ptr->csleep = 0;
-	if (r_ptr->flags7 & (RF7_HAS_LITE_1 | RF7_HAS_LITE_2))
-		p_ptr->update |= (PU_MON_LITE);
+	if (r_ptr->flags7 & (RF7_HAS_LITE_1 | RF7_HAS_LITE_2)) p_ptr->update |= (PU_MON_LITE);
 
 	/* Extract monster name (or "it") */
 	monster_desc(m_name, m_ptr, 0);
@@ -2329,7 +2304,6 @@ static void py_attack_aux(int y, int x, int mode)
 
 					teleport_away(c_ptr->m_idx, 50);
 					num = p_ptr->num_blow + 1; /* Can't hit it anymore! */
-					no_extra = TRUE;
 				}
 			}
 
@@ -2609,7 +2583,7 @@ static bool pattern_seq(int c_y, int c_x, int n_y, int n_x)
 		}
 		else
 		{
-			byte ok_move = FEAT_PATTERN_START;
+			byte ok_move;
 			switch (cave[c_y][c_x].feat)
 			{
 				case FEAT_PATTERN_1:
@@ -2627,9 +2601,9 @@ static bool pattern_seq(int c_y, int c_x, int n_y, int n_x)
 				default:
 					if (wizard)
 #ifdef JP
-						msg_format("ʥѥԡ%d", cave[c_y][c_x]);
+						msg_format("ʥѥԡ%d", cave[c_y][c_x].feat);
 #else
-						msg_format("Funny Pattern walking, %d.", cave[c_y][c_x]);
+						msg_format("Funny Pattern walking, %d.", cave[c_y][c_x].feat);
 #endif
 					return TRUE; /* Goof-up */
 			}
@@ -2722,7 +2696,6 @@ void move_player(int dir, int do_pickup)
 				p_ptr->oldpx = 1;
 			}
 
-			p_ptr->leftbldg = TRUE;
 			p_ptr->leaving = TRUE;
 
 			return;
@@ -2759,7 +2732,7 @@ void move_player(int dir, int do_pickup)
 		    ((cave_floor_bold(y, x)) || p_can_pass_walls))
 		{
 			m_ptr->csleep = 0;
-			p_ptr->update |= (PU_MON_LITE);
+			if (r_info[m_ptr->r_idx].flags7 & (RF7_HAS_LITE_1 | RF7_HAS_LITE_2)) p_ptr->update |= (PU_MON_LITE);
 
 			/* Extract monster name (or "it") */
 			monster_desc(m_name, m_ptr, 0);
@@ -3154,7 +3127,7 @@ msg_print("ˤ֤ä");
 			disturb(0, 0);
 
 			/* Hack -- Enter store */
-			command_new = 253;
+			command_new = SPECIAL_KEY_STORE;
 		}
 
 		/* Handle "building doors" -KMW- */
@@ -3165,7 +3138,7 @@ msg_print("ˤ֤ä");
 			disturb(0, 0);
 
 			/* Hack -- Enter building */
-			command_new = 254;
+			command_new = SPECIAL_KEY_BUILDING;
 		}
 
 		/* Handle quest areas -KMW- */
@@ -3175,7 +3148,7 @@ msg_print("ˤ֤ä");
 			disturb(0, 0);
 
 			/* Hack -- Enter quest level */
-			command_new = 255;
+			command_new = SPECIAL_KEY_QUEST;
 		}
 
 		else if (cave[y][x].feat == FEAT_QUEST_EXIT)
@@ -3189,7 +3162,7 @@ msg_print("ˤ֤ä");
 #else
 				msg_print("You accomplished your quest!");
 #endif
-
+				sound(SOUND_QUEST);
 				msg_print(NULL);
 			}
 
@@ -3646,8 +3619,7 @@ static bool run_test(void)
 	/* Look at every newly adjacent square. */
 	for (i = -max; i <= max; i++)
 	{
-		s16b this_o_idx, next_o_idx = 0;
-
+		s16b this_o_idx, next_o_idx;
 
 		/* New direction */
 		new_dir = cycle[chome[prev_dir] + i];
@@ -3681,7 +3653,7 @@ static bool run_test(void)
 			next_o_idx = o_ptr->next_o_idx;
 
 			/* Visible object */
-			if (o_ptr->marked) return (TRUE);
+			if (o_ptr->marked & OM_FOUND) return (TRUE);
 		}
 
 
