@@ -246,7 +246,7 @@ void do_cmd_wield(void)
 	if (cursed_p(&inventory[slot]))
 	{
 		/* Describe it */
-		object_desc(o_name, &inventory[slot], FALSE, 0);
+		object_desc(o_name, &inventory[slot], OD_OMIT_PREFIX | OD_NAME_ONLY);
 
 		/* Message */
 #ifdef JP
@@ -268,7 +268,7 @@ void do_cmd_wield(void)
 		char dummy[512];
 
 		/* Describe it */
-		object_desc(o_name, o_ptr, FALSE, 0);
+		object_desc(o_name, o_ptr, OD_OMIT_PREFIX | OD_NAME_ONLY);
 
 #ifdef JP
 sprintf(dummy, "%s{Ƥ}Ȥޤ", o_name);
@@ -286,7 +286,7 @@ sprintf(dummy, "%s{Ƥ}Ȥޤ", o_name);
 		char dummy[MAX_NLEN+80];
 
 		/* Describe it */
-		object_desc(o_name, o_ptr, FALSE, 0);
+		object_desc(o_name, o_ptr, OD_OMIT_PREFIX | OD_NAME_ONLY);
 
 #ifdef JP
 		sprintf(dummy, "%sȵ۷쵴ˤʤޤǤ", o_name);
@@ -310,11 +310,11 @@ sprintf(dummy, "%s{Ƥ}Ȥޤ", o_name);
 			quest[i].status = QUEST_STATUS_COMPLETED;
 			quest[i].complev = (byte)p_ptr->lev;
 #ifdef JP
-msg_print("Ȥã");
+			msg_print("Ȥã");
 #else
 			msg_print("You completed your quest!");
 #endif
-
+			sound(SOUND_QUEST);
 			msg_print(NULL);
 		}
 	}
@@ -358,9 +358,12 @@ msg_print("Ȥã");
 	/* Wear the new stuff */
 	object_copy(o_ptr, q_ptr);
 
+	/* Player touches it */
+	o_ptr->marked |= OM_TOUCHED;
+
 	/* Forget stack */
 	o_ptr->next_o_idx = 0;
-	
+
 	/* Forget location */
 	o_ptr->iy = o_ptr->ix = 0;
 
@@ -409,7 +412,7 @@ msg_print("Ȥã");
 	}
 
 	/* Describe the result */
-	object_desc(o_name, o_ptr, TRUE, 3);
+	object_desc(o_name, o_ptr, 0);
 
 	/* Message */
 #ifdef JP
@@ -466,6 +469,9 @@ msg_print("Ȥã");
 		p_ptr->update |= (PU_BONUS);
 		handle_stuff();
 
+		/* Load an autopick preference file */
+		autopick_load_pref(FALSE);
+
 		lite_spot(py, px);
 	}
 
@@ -681,6 +687,64 @@ void do_cmd_destroy(void)
 	}
 
 
+	/* Verify unless quantity given */
+	if (!force && (!(auto_destroy && (object_value(o_ptr) < 1))))
+	{
+		object_desc(o_name, o_ptr, OD_OMIT_PREFIX);
+
+		/* Make a verification */
+		sprintf(out_val, 
+#ifdef JP
+			"%sޤ? [y/n/Auto]",
+#else
+			"Really destroy %s? [y/n/Auto]",
+#endif
+			o_name);
+
+		msg_print(NULL);
+
+		/* HACK : Add the line to message buffer */
+		message_add(out_val);
+		p_ptr->window |= (PW_MESSAGE);
+		window_stuff();
+
+		/* Get an acceptable answer */
+		while (TRUE)
+		{
+			char i;
+
+			/* Prompt */
+			prt(out_val, 0, 0);
+
+			i = inkey();
+
+			/* Erase the prompt */
+			prt("", 0, 0);
+
+			if (i == 'y' || i == 'Y')
+			{
+				break;
+			}
+			if (i == ESCAPE || i == 'n' || i == 'N')
+			{
+				/* Cancel */
+				return;
+			}
+			if (i == 'A')
+			{
+				/* Add an auto-destroy preference line */
+				if (autopick_autoregister(o_ptr))
+				{
+					/* Auto-destroy it */
+					autopick_alter_item(item, TRUE);
+				}
+
+				/* The object is already destroyed. */
+				return;
+			}
+		} /* while (TRUE) */
+	}
+
 	/* See how many items */
 	if (o_ptr->number > 1)
 	{
@@ -691,29 +755,12 @@ void do_cmd_destroy(void)
 		if (amt <= 0) return;
 	}
 
-
 	/* Describe the object */
 	old_number = o_ptr->number;
 	o_ptr->number = amt;
-	object_desc(o_name, o_ptr, TRUE, 3);
+	object_desc(o_name, o_ptr, 0);
 	o_ptr->number = old_number;
 
-	/* Verify unless quantity given */
-	if (!force)
-	{
-		if (!(auto_destroy && (object_value(o_ptr) < 1)))
-		{
-			/* Make a verification */
-#ifdef JP
-		sprintf(out_val, "%sޤ? ", o_name);
-#else
-			sprintf(out_val, "Really destroy %s? ", o_name);
-#endif
-
-			if (!get_check(out_val)) return;
-		}
-	}
-
 	/* Take a turn */
 	energy_use = 100;
 
@@ -730,7 +777,6 @@ void do_cmd_destroy(void)
 		msg_format("You cannot destroy %s.", o_name);
 #endif
 
-
 		/* Done */
 		return;
 	}
@@ -853,7 +899,7 @@ void do_cmd_observe(void)
 
 
 	/* Description */
-	object_desc(o_name, o_ptr, TRUE, 3);
+	object_desc(o_name, o_ptr, 0);
 
 	/* Describe */
 #ifdef JP
@@ -981,7 +1027,7 @@ void do_cmd_inscribe(void)
 	}
 
 	/* Describe the activity */
-	object_desc(o_name, o_ptr, TRUE, 3);
+	object_desc(o_name, o_ptr, 0);
 
 	/* Message */
 #ifdef JP
@@ -1861,6 +1907,8 @@ void ang_sort_swap_hook(vptr u, vptr v, int a, int b)
 
 	u16b holder;
 
+	(void)v; /* Unused */
+
 	/* Swap */
 	holder = who[a];
 	who[a] = who[b];
@@ -2025,9 +2073,9 @@ void do_cmd_query_symbol(void)
 			}
 
 #ifdef JP
-			if (strstr(temp2, temp) || strstr_j(r_name + r_ptr->name, temp) )
+			if (my_strstr(temp2, temp) || my_strstr(r_name + r_ptr->name, temp))
 #else
-			if (strstr(temp2, temp))
+			if (my_strstr(temp2, temp))
 #endif
 				who[n++]=i;
 		}
@@ -2337,7 +2385,7 @@ if (!get_com("󥹥ʸϤƲ( or ^A,^U,^N,^M̾):", &sym))
 		    for (xx=0; temp2[xx] && xx<80; xx++)
 		      if (isupper(temp2[xx])) temp2[xx]=tolower(temp2[xx]);
 
-		    if (strstr(temp2, temp) || strstr_j(r_name + r_ptr->name, temp) ) who[n++]=i;
+		    if (my_strstr(temp2, temp) || my_strstr(r_name + r_ptr->name, temp) ) who[n++]=i;
 		}
 
 		else if (all || (r_ptr->d_char == sym)) who[n++] = i;
