@@ -77,12 +77,12 @@ static const char *spell_tips[MAX_REALM][32] =
 		"ꤷʸΥ󥹥򸽺ߤγä롣񹳤̵",
 
 		"󥹥λĤϡϡԡɤΤ롣",
-		"󥹥1μʬζ᤯˰󤻤롣",
 		"ֻ˾夫γ˥ƥݡȤ롣",
-		"θġ",
+		"Υ줿֤Υƥư롣",
 		"᤯ƤΥ󥹥櫡⡢ʡƥƥΤ롣",
 		"դΥƥࡢ󥹥Ϸ˲롣",
 		"γΤʵפ˾Ȥ餷󥸥⤹٤ƤΥƥΤ롣ˡ֥ƥѥǽϤ롣",
+		"볦Υ󥹥ƥݡȤ롣",
 		"ûΥλꤷ˥ƥݡȤ롣",
 		"ƥ1Ĥ򤪶Ѥ롣",
 		"ʬμϤˤ󥹥򸽺ߤγä롣񹳤̵",
@@ -1165,70 +1165,30 @@ static bool cast_sorcery_spell(int spell)
 	case 20: /* Probing */
 		probing();
 		break;
-	case 21: /* Teleport monster to player */
-	{
-		monster_type *m_ptr;
-		monster_race *r_ptr;
-		char m_name[80];
-
-		if (!target_set(TARGET_KILL)) return FALSE;
-		if (!cave[target_row][target_col].m_idx) break;
-		if (!player_has_los_bold(target_row, target_col)) break;
-		m_ptr = &m_list[cave[target_row][target_col].m_idx];
-		r_ptr = &r_info[m_ptr->r_idx];
-		monster_desc(m_name, m_ptr, 0);
-		if (r_ptr->flags3 & (RF3_RES_TELE))
-		{
-			if (r_ptr->flags1 & (RF1_UNIQUE))
-			{
-				r_ptr->r_flags3 |= RF3_RES_TELE;
-#ifdef JP
-				msg_format("%sˤϸ̤ʤä", m_name);
-#else
-				msg_format("%s is unaffected!", m_name);
-#endif
-				break;
-			}
-			else if (r_ptr->level > randint1(100))
-			{
-				r_ptr->r_flags3 |= RF3_RES_TELE;
-#ifdef JP
-				msg_format("%sˤ롪", m_name);
-#else
-				msg_format("%s resists!", m_name);
-#endif
-				break;
-			}
-		}
-#ifdef JP
-		msg_format("%sᤷ", m_name);
-#else
-		msg_format("You command %s to return.", m_name);
-#endif
-		teleport_to_player(cave[target_row][target_col].m_idx, 100);
-		break;
-	}
-	case 22: /* Teleport Level */
+	case 21: /* Teleport Level */
 		(void)teleport_player_level();
 		break;
-	case 23: /* Death Ray */
+	case 22: /* Telekinesis */
 		if (!get_aim_dir(&dir)) return FALSE;
 
-		(void)death_ray(dir, plev);
+		fetch(dir, plev * 15 / 10, FALSE);
 		break;
-	case 24: /* Detection */
+	case 23: /* Detection */
 		(void)detect_all(DETECT_RAD_DEFAULT);
 		break;
-	case 25: /* Word of Destruction */
+	case 24: /* Word of Destruction */
 		destroy_area(py, px, 15, TRUE);
 		break;
-	case 26: /* Clairvoyance */
+	case 25: /* Clairvoyance */
 		wiz_lite();
 		if (!p_ptr->telepathy)
 		{
 			(void)set_tim_esp(p_ptr->tim_esp + randint1(30) + 25);
 		}
 		break;
+	case 26: /* Banish Monsters */
+		banish_monsters(MAX_SIGHT * 5);
+		break;
 	case 27: /* Dimension Door */
 #ifdef JP
 		msg_print("⤬ŪϤǲ");
