@@ -4549,6 +4549,10 @@ void play_game(bool new_game)
 		browse_chuukei();
 		return;
 	}
+	else if (chuukei_server)
+	{
+		prepare_chuukei_hooks();
+	}
 #endif
 
 	/* Make sure main term is active */
