@@ -2886,44 +2886,44 @@ bool hp_player(int num)
 		if (num < 5)
 		{
 #ifdef JP
-msg_print("ʬɤʤä");
+			msg_print("ʬɤʤä");
 #else
 			msg_print("You feel a little better.");
 #endif
-
+			sound(SOUND_HEAL);
 		}
 
 		/* Heal 5-14 */
 		else if (num < 15)
 		{
 #ifdef JP
-msg_print("ʬɤʤä");
+			msg_print("ʬɤʤä");
 #else
 			msg_print("You feel better.");
 #endif
-
+			sound(SOUND_HEAL);
 		}
 
 		/* Heal 15-34 */
 		else if (num < 35)
 		{
 #ifdef JP
-msg_print("ȤƤⵤʬɤʤä");
+			msg_print("ȤƤⵤʬɤʤä");
 #else
 			msg_print("You feel much better.");
 #endif
-
+			sound(SOUND_HEAL);
 		}
 
 		/* Heal 35+ */
 		else
 		{
 #ifdef JP
-msg_print("Ҥ礦˵ʬɤʤä");
+			msg_print("Ҥ礦˵ʬɤʤä");
 #else
 			msg_print("You feel very good.");
 #endif
-
+			sound(SOUND_X_HEAL);
 		}
 
 		/* Notice */
@@ -3257,6 +3257,7 @@ msg_print("ʤѲˬ򴶤...");
 	{
 		char effect_msg[80] = "";
 		int new_race, expfact, goalexpfact;
+		int old_race = p_ptr->prace;
 
 		/* Some form of racial polymorph... */
 		power -= 10;
@@ -3420,6 +3421,10 @@ msg_print("̯ʤ餤̤ˤʤä롣");
 		p_ptr->update |= (PU_BONUS);
 
 		handle_stuff();
+
+		/* Load an autopick preference file */
+		if (old_race != p_ptr->prace) autopick_load_pref(FALSE);
+
 		lite_spot(py, px);
 	}
 #endif /* #if 0 */
