@@ -1251,11 +1251,10 @@ why = "󥹥¿";
 				 !p_ptr->inside_quest)
 		{
 			/* Require "goodness" */
-			if ((feeling > 9) ||
-			    ((dun_level >= 5) && (feeling > 8)) ||
-			    ((dun_level >= 10) && (feeling > 7)) ||
-			    ((dun_level >= 20) && (feeling > 6)) ||
-			    ((dun_level >= 40) && (feeling > 5)))
+			if (((dun_level >= 5) && (feeling > 9)) ||
+			    ((dun_level >= 15) && (feeling > 8)) ||
+			    ((dun_level >= 40) && (feeling > 7)) ||
+			    ((dun_level >= 70) && (feeling > 6)))
 			{
 				/* Give message to cheaters */
 				if (cheat_room || cheat_hear ||
