@@ -65,6 +65,15 @@ static u32b	v_check = 0L;
  */
 static u32b	x_check = 0L;
 
+/*
+ * Hack -- Japanese Kanji code
+ * 0: Unknown
+ * 1: ASCII
+ * 2: EUC
+ * 3: SJIS
+ */
+static byte kanji_code = 0;
+
 /*
  * Array for object memories (awareness etc.)
  */
@@ -257,8 +266,40 @@ static void rd_string(char *str, int max)
 
 	/* Terminate */
 	str[max-1] = '\0';
+
+
 #ifdef JP
-	codeconv(str); /* Ѵ */
+	/* Convert Kanji code */
+	switch (kanji_code)
+	{
+#ifdef SJIS
+	case 2:
+		/* EUC to SJIS */
+		euc2sjis(str);
+		break;
+#endif
+
+#ifdef EUC
+	case 3:
+		/* SJIS to EUC */
+		sjis2euc(str);
+		break;
+#endif
+
+	case 0:
+	{
+		/* δɤ饷ƥδɤѴ */
+		byte code = codeconv(str);
+
+		/* ɤȽ顢Ͽ */
+		if (code) kanji_code = code;
+
+		break;
+	}
+	default:
+		/* No conversion needed */
+		break;
+	}
 #endif
 }
 
@@ -1048,7 +1089,7 @@ static void rd_extra(void)
 	rd_s16b(&p_ptr->inside_arena);
 	rd_s16b(&p_ptr->inside_quest);
 	rd_byte(&p_ptr->exit_bldg);
-	rd_byte(&p_ptr->leftbldg);
+	rd_byte(&tmp8u);
 
 	rd_s16b(&p_ptr->oldpx);
 	rd_s16b(&p_ptr->oldpy);
@@ -1160,7 +1201,10 @@ static void rd_extra(void)
 
 	rd_byte(&p_ptr->confusing);
 	rd_byte(&tmp8u); /* oops */
-	rd_byte(&tmp8u); /* oops */
+
+	rd_byte(&tmp8u);
+	p_ptr->autopick_autoregister = tmp8u ? TRUE : FALSE;
+
 	rd_byte(&tmp8u); /* oops */
 	rd_byte(&p_ptr->searching);
 	rd_byte(&maximize_mode);
@@ -1190,12 +1234,21 @@ static void rd_extra(void)
 	death = tmp8u;
 
 	/* Read "feeling" */
-	rd_byte(&tmp8u);
-	feeling = tmp8u;
+	rd_byte(&p_ptr->feeling);
 
-	/* Turn of last "feeling" */
+	/* Turn when level began */
 	rd_s32b(&old_turn);
 
+	if (k_older_than(1, 0, 1))
+	{
+		p_ptr->feeling_turn = old_turn;
+	}
+	else
+	{
+		/* Turn of last "feeling" */
+		rd_s32b(&p_ptr->feeling_turn);
+	}
+
 	/* Current turn */
 	rd_s32b(&turn);
 
@@ -1262,6 +1315,9 @@ static errr rd_inventory(void)
 		{
 			if (q_ptr->k_idx)
 			{
+				/* Player touches it */
+				q_ptr->marked |= OM_TOUCHED;
+
 				/* Copy object */
 				object_copy(&inventory[n], q_ptr);
 
@@ -1295,6 +1351,9 @@ static errr rd_inventory(void)
 				/* Get a slot */
 				n = slot++;
 
+				/* Player touches it */
+				q_ptr->marked |= OM_TOUCHED;
+
 				/* Copy object */
 				object_copy(&inventory[n], q_ptr);
 
@@ -1732,7 +1791,13 @@ static errr rd_savefile_new_aux(void)
 	rd_u32b(&tmp32u);
 
 	/* Later use (always zero) */
-	rd_u32b(&tmp32u);
+	rd_u16b(&tmp16u);
+
+	/* Later use (always zero) */
+	rd_byte(&tmp8u);
+
+	/* Kanji code */
+	rd_byte(&kanji_code);
 
 
 	/* Read RNG state */
@@ -1790,13 +1855,8 @@ static errr rd_savefile_new_aux(void)
 	/* Read the available records */
 	for (i = 0; i < tmp16u; i++)
 	{
-		monster_race *r_ptr;
-
 		/* Read the lore */
 		rd_lore(i);
-
-		/* Access that monster */
-		r_ptr = &r_info[i];
 	}
 
 #ifdef JP
@@ -1850,7 +1910,6 @@ static errr rd_savefile_new_aux(void)
 	p_ptr->arena_number = 0;
 	p_ptr->inside_arena = 0;
 	p_ptr->inside_quest = 0;
-	p_ptr->leftbldg = FALSE;
 	p_ptr->exit_bldg = TRUE;
 
 	/* Start in town 1 */
