@@ -98,8 +98,7 @@ static bool know_damage(int r_idx, int i)
 static void roff_aux(int r_idx, int remem)
 {
 	monster_race    *r_ptr = &r_info[r_idx];
-	bool            old = FALSE;
-	bool            sin = FALSE;
+	bool            old;
 	int             m, n, r;
 	cptr            p, q;
 	int             msex = 0;
@@ -107,12 +106,14 @@ static void roff_aux(int r_idx, int remem)
 	bool            breath = FALSE;
 	bool            magic = FALSE;
 	u32b            flags1, flags2, flags3, flags4, flags5, flags6, flags7;
-	int             vn = 0;
+	int             vn;
 	byte			color[64];
 	cptr            vp[64];
 	monster_race    save_mem;
 #ifdef JP
 	char            jverb_buf[64];
+#else
+	bool            sin = FALSE;
 #endif
 
 	/* Descriptions */
@@ -439,118 +440,116 @@ static void roff_aux(int r_idx, int remem)
 
 
 	/* Describe movement */
-	if (TRUE)
+
+	/* Introduction */
+	if (old)
 	{
-		/* Introduction */
-		if (old)
+#ifdef JP
+		roff("");
+#else
+		roff(", and ");
+#endif
+	}
+	else
+	{
+#ifdef JP
+		roff(format("%^s", wd_he[msex]));
+#else
+		roff(format("%^s ", wd_he[msex]));
+#endif
+		old = TRUE;
+	}
+
+#ifndef JP
+	roff("moves");
+#endif
+
+	/* Random-ness */
+	if ((flags1 & RF1_RAND_50) || (flags1 & RF1_RAND_25))
+	{
+		/* Adverb */
+		if ((flags1 & RF1_RAND_50) && (flags1 & RF1_RAND_25))
+		{
+#ifdef JP
+			roff("ʤ");
+#else
+			roff(" extremely");
+#endif
+		}
+		else if (flags1 & RF1_RAND_50)
+		{
+#ifdef JP
+			roff("ʬ");
+#else
+			roff(" somewhat");
+#endif
+		}
+		else if (flags1 & RF1_RAND_25)
 		{
 #ifdef JP
 			roff("");
 #else
-			roff(", and ");
-#endif
-		}
-		else
-		{
-#ifdef JP
-			roff(format("%^s", wd_he[msex]));
-#else
-			roff(format("%^s ", wd_he[msex]));
-#endif
-			old = TRUE;
-		}
-
-#ifndef JP
-		roff("moves");
-#endif
-
-		/* Random-ness */
-		if ((flags1 & RF1_RAND_50) || (flags1 & RF1_RAND_25))
-		{
-			/* Adverb */
-			if ((flags1 & RF1_RAND_50) && (flags1 & RF1_RAND_25))
-			{
-#ifdef JP
-				roff("ʤ");
-#else
-				roff(" extremely");
-#endif
-			}
-			else if (flags1 & RF1_RAND_50)
-			{
-#ifdef JP
-				roff("ʬ");
-#else
-				roff(" somewhat");
-#endif
-			}
-			else if (flags1 & RF1_RAND_25)
-			{
-#ifdef JP
-				roff("");
-#else
-				roff(" a bit");
-#endif
-			}
-
-			/* Adjective */
-#ifdef JP
-			roff("Ե§");
-#else
-			roff(" erratically");
-#endif
-
-			/* Hack -- Occasional conjunction */
-#ifdef JP
-			if (speed != 110) roff("");
-#else
-			if (speed != 110) roff(", and");
+			roff(" a bit");
 #endif
 		}
 
-		/* Speed */
-		if (speed > 110)
-		{
+		/* Adjective */
 #ifdef JP
-			if (speed > 139) c_roff(TERM_RED, "񤤤ۤ");
-			else if (speed > 134) c_roff(TERM_ORANGE, "");
-			else if (speed > 129) c_roff(TERM_ORANGE, "");
-			else if (speed > 124) c_roff(TERM_UMBER, "ʤ");
-			else if (speed < 120) c_roff(TERM_L_UMBER, "");
-			c_roff(TERM_L_RED, "᤯");
+		roff("Ե§");
 #else
-			if (speed > 130) c_roff(TERM_RED, " incredibly");
-			else if (speed > 120) c_roff(TERM_ORANGE, " very");
-			c_roff(TERM_L_RED, " quickly");
+		roff(" erratically");
 #endif
-		}
-		else if (speed < 110)
-		{
+
+		/* Hack -- Occasional conjunction */
 #ifdef JP
-			if (speed < 90) c_roff(TERM_L_GREEN, "񤤤ۤ");
-			else if (speed < 95) c_roff(TERM_BLUE, "");
-			else if (speed < 100) c_roff(TERM_BLUE, "ʤ");
-			else if (speed > 104) c_roff(TERM_GREEN, "");
-			c_roff(TERM_L_BLUE, "ä");
+		if (speed != 110) roff("");
 #else
-			if (speed < 90) c_roff(TERM_L_GREEN, " incredibly");
-			else if (speed < 100) c_roff(TERM_BLUE, " very");
-			c_roff(TERM_L_BLUE, " slowly");
-#endif
-		}
-		else
-		{
-#ifdef JP
-			c_roff(TERM_YELLOW, "̤®");
-#else
-			c_roff(TERM_YELLOW, " at normal speed");
-#endif
-		}
-#ifdef JP
-		roff("ưƤ");
+		if (speed != 110) roff(", and");
 #endif
 	}
 
+	/* Speed */
+	if (speed > 110)
+	{
+#ifdef JP
+		if (speed > 139) c_roff(TERM_RED, "񤤤ۤ");
+		else if (speed > 134) c_roff(TERM_ORANGE, "");
+		else if (speed > 129) c_roff(TERM_ORANGE, "");
+		else if (speed > 124) c_roff(TERM_UMBER, "ʤ");
+		else if (speed < 120) c_roff(TERM_L_UMBER, "");
+		c_roff(TERM_L_RED, "᤯");
+#else
+		if (speed > 130) c_roff(TERM_RED, " incredibly");
+		else if (speed > 120) c_roff(TERM_ORANGE, " very");
+		c_roff(TERM_L_RED, " quickly");
+#endif
+	}
+	else if (speed < 110)
+	{
+#ifdef JP
+		if (speed < 90) c_roff(TERM_L_GREEN, "񤤤ۤ");
+		else if (speed < 95) c_roff(TERM_BLUE, "");
+		else if (speed < 100) c_roff(TERM_BLUE, "ʤ");
+		else if (speed > 104) c_roff(TERM_GREEN, "");
+		c_roff(TERM_L_BLUE, "ä");
+#else
+		if (speed < 90) c_roff(TERM_L_GREEN, " incredibly");
+		else if (speed < 100) c_roff(TERM_BLUE, " very");
+		c_roff(TERM_L_BLUE, " slowly");
+#endif
+	}
+	else
+	{
+#ifdef JP
+		c_roff(TERM_YELLOW, "̤®");
+#else
+		c_roff(TERM_YELLOW, " at normal speed");
+#endif
+	}
+#ifdef JP
+	roff("ưƤ");
+#endif
+
 	/* The code above includes "attack speed" */
 	if (flags1 & RF1_NEVER_MOVE)
 	{
@@ -589,7 +588,6 @@ static void roff_aux(int r_idx, int remem)
 #else
 		roff(".  ");
 #endif
-		old = FALSE;
 	}
 
 
@@ -657,7 +655,6 @@ static void roff_aux(int r_idx, int remem)
 #endif
 
 		/* Group some variables */
-		if (TRUE)
 		{
 			long i, j;
 
@@ -675,7 +672,7 @@ static void roff_aux(int r_idx, int remem)
 			i = (long)r_ptr->mexp * r_ptr->level / p_ptr->max_plv;
 			j = ((((long)r_ptr->mexp * r_ptr->level % p_ptr->max_plv) *
 			       (long)1000 / p_ptr->max_plv + 5) / 10);
-			
+
 			/* Mention the experience */
 			roff(format(" is worth %ld.%02ld point%s", (long)i, (long)j,
 				    (((i == 1) && (j == 0)) ? "" : "s")));
@@ -1514,7 +1511,7 @@ static void roff_aux(int r_idx, int remem)
 	if (flags4 & RF4_BR_CHAO) {color[vn] = TERM_VIOLET; vp[vn++] = "chaos";}
 	if (flags3 & RF3_RES_NEXU) {color[vn] = TERM_VIOLET; vp[vn++] = "nexus";}
 	if (flags3 & RF3_RES_DISE) {color[vn] = TERM_VIOLET; vp[vn++] = "disenchantment";}
-	if (flags4 & RF4_BR_WALL) {color[vn] = TERM_UMBER; vp[vn++] = "sound";}
+	if (flags4 & RF4_BR_WALL) {color[vn] = TERM_UMBER; vp[vn++] = "force";}
 	if (flags4 & RF4_BR_INER) {color[vn] = TERM_SLATE; vp[vn++] = "inertia";}
 	if (flags4 & RF4_BR_TIME) {color[vn] = TERM_L_BLUE; vp[vn++] = "time";}
 	if (flags4 & RF4_BR_GRAV) {color[vn] = TERM_SLATE; vp[vn++] = "gravity";}
@@ -1725,14 +1722,14 @@ static void roff_aux(int r_idx, int remem)
 	/* Drops gold and/or items */
 	if (r_ptr->r_drop_gold || r_ptr->r_drop_item)
 	{
-		/* No "n" needed */
-		sin = FALSE;
-
 		/* Intro */
 #ifdef JP
 		roff(format("%^s", wd_he[msex]));
 #else
 		roff(format("%^s may carry", wd_he[msex]));
+
+		/* No "n" needed */
+		sin = FALSE;
 #endif
 
 		/* Count maximum drop */
@@ -1745,8 +1742,8 @@ static void roff_aux(int r_idx, int remem)
 			roff("Ĥ");
 #else
 			roff(" a");
-#endif
 			sin = TRUE;
+#endif
 		}
 
 		/* Two drops */
@@ -1786,8 +1783,8 @@ static void roff_aux(int r_idx, int remem)
 			p = "";
 #else
 			p = " good";
-#endif
 			sin = FALSE;
+#endif
 		}
 
 		/* Okay */
@@ -1802,8 +1799,8 @@ static void roff_aux(int r_idx, int remem)
 			/* Handle singular "an" */
 #ifndef JP
 			if (sin) roff("n");
-#endif
 			sin = FALSE;
+#endif
 
 			/* Dump "object(s)" */
 			if (p) roff(p);
@@ -1825,14 +1822,14 @@ static void roff_aux(int r_idx, int remem)
 		/* Treasures */
 		if (r_ptr->r_drop_gold)
 		{
+#ifndef JP
 			/* Cancel prefix */
 			if (!p) sin = FALSE;
 
 			/* Handle singular "an" */
-#ifndef JP
 			if (sin) roff("n");
-#endif
 			sin = FALSE;
+#endif
 
 			/* Dump "treasure(s)" */
 			if (p) roff(p);
@@ -2192,14 +2189,12 @@ void roff_top(int r_idx)
 
 	/* Append the "standard" attr/char info */
 	Term_addstr(-1, TERM_WHITE, " ('");
-	Term_addch(a1, c1);
-	if (use_bigtile && (a1 & 0x80)) Term_addch(255, -1);
+	Term_add_bigch(a1, c1);
 	Term_addstr(-1, TERM_WHITE, "')");
 
 	/* Append the "optional" attr/char info */
 	Term_addstr(-1, TERM_WHITE, "/('");
-	Term_addch(a2, c2);
-	if (use_bigtile && (a2 & 0x80)) Term_addch(255, -1);
+	Term_add_bigch(a2, c2);
 	Term_addstr(-1, TERM_WHITE, "'):");
 
 	/* Wizards get extra info */
