@@ -481,7 +481,7 @@ void curse_equipment(int chance, int heavy_chance)
 	if ((o3 & TR3_BLESSED) && (randint1(888) > chance))
 	{
 		char o_name[256];
-		object_desc(o_name, o_ptr, FALSE, 0);
+		object_desc(o_name, o_ptr, OD_OMIT_PREFIX | OD_NAME_ONLY);
 #ifdef JP
 msg_format("%sϼķ֤", o_name,
 #else
@@ -845,7 +845,7 @@ bool make_attack_spell(int m_idx)
 	bool direct = TRUE;
 
 	/* Damage of spell */
-	int dam = 0;
+	int dam;
 
 	/* Cannot cast spells when confused */
 	if (m_ptr->confused) {m_ptr->target_y = 0;m_ptr->target_x = 0;return (FALSE);}
@@ -876,6 +876,10 @@ bool make_attack_spell(int m_idx)
 
 	/* XXX XXX XXX Handle "track_target" option (?) */
 
+	/* Extract the racial spell flags */
+	f4 = r_ptr->flags4;
+	f5 = r_ptr->flags5;
+	f6 = r_ptr->flags6;
 
 	/* Hack -- require projectable player */
 	if (normal)
@@ -913,11 +917,6 @@ bool make_attack_spell(int m_idx)
 	/* Extract the monster level */
 	rlev = ((r_ptr->level >= 1) ? r_ptr->level : 1);
 
-	/* Extract the racial spell flags */
-	f4 = r_ptr->flags4;
-	f5 = r_ptr->flags5;
-	f6 = r_ptr->flags6;
-
 	if (!X_stupid_monsters)
 	{
 		/* Forbid inate attacks sometimes */
@@ -1068,6 +1067,7 @@ bool make_attack_spell(int m_idx)
 			if (blind) msg_format("%^s shoots something.", m_name);
 			else msg_format("%^s fires a rocket.", m_name);
 #endif
+			sound(SOUND_ROCKET);
 			dam = (m_ptr->hp / 4) > 800 ? 800 : (m_ptr->hp / 4);
 			breath(y, x, m_idx, GF_ROCKET, dam, 2, FALSE);
 			update_smart_learn(m_idx, DRS_SHARD);
@@ -2421,7 +2421,7 @@ bool make_attack_spell(int m_idx)
 			if (!direct) break;
 			disturb(1, 0);
 #ifdef JP
-			msg_format("%^sǤμä", m_name);
+			msg_format("%^s<Ǥμ>ä", m_name);
 #else
 			msg_format("%^s invokes the Hand of Doom!", m_name);
 #endif
@@ -2496,6 +2496,8 @@ bool make_attack_spell(int m_idx)
 #endif
 			}
 
+			sound(SOUND_M_HEAL);
+
 			/* Redraw (later) if needed */
 			if (p_ptr->health_who == m_idx) p_ptr->redraw |= (PR_HEALTH);
 
@@ -2714,7 +2716,7 @@ bool make_attack_spell(int m_idx)
 		{
 			disturb(1, 0);
 #ifdef JP
-			msg_format("%^sŤˤĤ֤䤤", m_name);		
+			msg_format("%^sŤˤĤ֤䤤", m_name);
 #else
 			msg_format("%^s mutters quietly.", m_name);
 #endif
@@ -2722,7 +2724,7 @@ bool make_attack_spell(int m_idx)
 			break;
 		}
 
-		/* RF6_SUMMON_KIN */
+		/* RF6_S_KIN */
 		case 160+16:
 		{
 			disturb(1, 0);
@@ -2735,6 +2737,7 @@ bool make_attack_spell(int m_idx)
 			else msg_format("%^s magically summons %s %s.", m_name, m_poss,
 				((r_ptr->flags1) & RF1_UNIQUE ? "minions" : "kin"));
 #endif
+			sound(SOUND_SUMMON);
 			summon_kin_type = r_ptr->d_char; /* Big hack */
 
 			for (k = 0; k < 6; k++)
@@ -2762,6 +2765,7 @@ bool make_attack_spell(int m_idx)
 			else msg_format("%^s magically summons Cyberdemons!", m_name);
 			if (blind && count) msg_print("You hear heavy steps nearby.");
 #endif
+			sound(SOUND_SUMMON);
 			summon_cyber(m_idx, y, x);
 			break;
 		}
@@ -2777,6 +2781,7 @@ bool make_attack_spell(int m_idx)
 			if (blind) msg_format("%^s mumbles.", m_name);
 			else msg_format("%^s magically summons help!", m_name);
 #endif
+			sound(SOUND_SUMMON);
 
 			for (k = 0; k < 1; k++)
 			{
@@ -2801,6 +2806,7 @@ bool make_attack_spell(int m_idx)
 			if (blind) msg_format("%^s mumbles.", m_name);
 			else msg_format("%^s magically summons monsters!", m_name);
 #endif
+			sound(SOUND_SUMMON);
 
 			for (k = 0; k < 8; k++)
 			{
@@ -2825,6 +2831,7 @@ bool make_attack_spell(int m_idx)
 			if (blind) msg_format("%^s mumbles.", m_name);
 			else msg_format("%^s magically summons ants.", m_name);
 #endif
+			sound(SOUND_SUMMON);
 
 			for (k = 0; k < 6; k++)
 			{
@@ -2849,6 +2856,7 @@ bool make_attack_spell(int m_idx)
 			if (blind) msg_format("%^s mumbles.", m_name);
 			else msg_format("%^s magically summons spiders.", m_name);
 #endif
+			sound(SOUND_SUMMON);
 
 			for (k = 0; k < 6; k++)
 			{
@@ -2873,6 +2881,7 @@ bool make_attack_spell(int m_idx)
 			if (blind) msg_format("%^s mumbles.", m_name);
 			else msg_format("%^s magically summons hounds.", m_name);
 #endif
+			sound(SOUND_SUMMON);
 
 			for (k = 0; k < 6; k++)
 			{
@@ -2897,6 +2906,7 @@ bool make_attack_spell(int m_idx)
 			if (blind) msg_format("%^s mumbles.", m_name);
 			else msg_format("%^s magically summons hydras.", m_name);
 #endif
+			sound(SOUND_SUMMON);
 
 			for (k = 0; k < 6; k++)
 			{
@@ -2921,6 +2931,7 @@ bool make_attack_spell(int m_idx)
 			if (blind) msg_format("%^s mumbles.", m_name);
 			else msg_format("%^s magically summons an angel!", m_name);
 #endif
+			sound(SOUND_SUMMON);
 
 			for (k = 0; k < 1; k++)
 			{
@@ -2945,6 +2956,7 @@ bool make_attack_spell(int m_idx)
 			if (blind) msg_format("%^s mumbles.", m_name);
 			else msg_format("%^s magically summons a hellish adversary!", m_name);
 #endif
+			sound(SOUND_SUMMON);
 
 			for (k = 0; k < 1; k++)
 			{
@@ -2969,6 +2981,7 @@ bool make_attack_spell(int m_idx)
 			if (blind) msg_format("%^s mumbles.", m_name);
 			else msg_format("%^s magically summons an undead adversary!", m_name);
 #endif
+			sound(SOUND_SUMMON);
 
 			for (k = 0; k < 1; k++)
 			{
@@ -2993,6 +3006,7 @@ bool make_attack_spell(int m_idx)
 			if (blind) msg_format("%^s mumbles.", m_name);
 			else msg_format("%^s magically summons a dragon!", m_name);
 #endif
+			sound(SOUND_SUMMON);
 
 			for (k = 0; k < 1; k++)
 			{
@@ -3017,6 +3031,7 @@ bool make_attack_spell(int m_idx)
 			if (blind) msg_format("%^s mumbles.", m_name);
 			else msg_format("%^s magically summons greater undead!", m_name);
 #endif
+			sound(SOUND_SUMMON);
 
 			for (k = 0; k < 8; k++)
 			{
@@ -3041,6 +3056,7 @@ bool make_attack_spell(int m_idx)
 			if (blind) msg_format("%^s mumbles.", m_name);
 			else msg_format("%^s magically summons ancient dragons!", m_name);
 #endif
+			sound(SOUND_SUMMON);
 
 			for (k = 0; k < 8; k++)
 			{
@@ -3065,6 +3081,7 @@ bool make_attack_spell(int m_idx)
 			if (blind) msg_format("%^s mumbles.", m_name);
 			else msg_format("%^s magically summons a hellish adversary!", m_name);
 #endif
+			sound(SOUND_SUMMON);
 
 			for (k = 0; k < 1; k++)
 			{
@@ -3089,6 +3106,7 @@ bool make_attack_spell(int m_idx)
 			if (blind) msg_format("%^s mumbles.", m_name);
 			else msg_format("%^s magically summons special opponents!", m_name);
 #endif
+			sound(SOUND_SUMMON);
 
 			for (k = 0; k < 8; k++)
 			{
