@@ -171,7 +171,7 @@ static int racial_aux(power_desc_type *pd_ptr)
 }
 
 /**** The monster bashing code. -LM- ****/
-static bool do_cmd_shield_bash()
+static bool do_cmd_shield_bash(void)
 {
 	int bash_chance, bash_quality, bash_dam;
 	int y, x, dir = 0;
@@ -182,8 +182,10 @@ static bool do_cmd_shield_bash()
 	monster_type *m_ptr;
 	monster_race *r_ptr;
 
+	o_ptr = &inventory[INVEN_ARM];
+
 	/* No shield on arm, no bash.  */
-	if (!inventory[INVEN_ARM].k_idx)
+	if (!o_ptr->k_idx)
 	{
 #ifdef JP
 		msg_print("Ƥʤ");
@@ -193,8 +195,6 @@ static bool do_cmd_shield_bash()
 		return (FALSE);
 	}
 
-	o_ptr = &inventory[INVEN_ARM];
-
 	/* Only works on adjacent monsters */
 	if (!get_rep_dir(&dir)) return (FALSE);   /* was get_aim_dir */
 	y = py + ddy[dir];
@@ -237,10 +237,10 @@ static bool do_cmd_shield_bash()
 
 		/* Calculate attack quality, a mix of momentum and accuracy. */
 		bash_quality = p_ptr->skill_thn + (p_ptr->wt / 8) +
-			(p_ptr->total_weight / 80) + (inventory[INVEN_ARM].weight / 3);
+			(p_ptr->total_weight / 80) + (o_ptr->weight / 3);
 
 		/* Calculate damage.  Big shields are deadly. */
-		bash_dam = damroll(inventory[INVEN_ARM].dd, inventory[INVEN_ARM].ds);
+		bash_dam = damroll(o_ptr->dd, o_ptr->ds);
 
 		/* Multiply by quality and experience factors */
 		bash_dam *= bash_quality / 20 + p_ptr->lev / 7;
@@ -330,7 +330,7 @@ static bool do_cmd_shield_bash()
 }
 
 /* Mei-kyo-Shi-Sui */
-static bool do_cmd_restore_mana()
+static bool do_cmd_restore_mana(void)
 {
 	if (total_friends)
 	{
@@ -373,14 +373,13 @@ static bool item_tester_hook_bows_and_ammos(object_type *o_ptr)
 	return (FALSE);
 }
 
-static bool do_cmd_identify_bows_and_ammos()
+static bool do_cmd_identify_bows_and_ammos(void)
 {
 	int item;
 	cptr q, s;
 	object_type *o_ptr;
 	char o_name[MAX_NLEN];
 	bool old_known;
-	int idx;
 
 	item_tester_hook = item_tester_hook_bows_and_ammos;
 
@@ -415,7 +414,7 @@ static bool do_cmd_identify_bows_and_ammos()
 	handle_stuff();
 
 	/* Description */
-	object_desc(o_name, o_ptr, TRUE, 3);
+	object_desc(o_name, o_ptr, 0);
 
 	/* Describe */
 	if (item >= INVEN_WIELD)
@@ -450,9 +449,7 @@ static bool do_cmd_identify_bows_and_ammos()
 	else identify_item(o_ptr);
 
 	/* Auto-inscription/destroy */
-	idx = is_autopick(o_ptr);
-	auto_inscribe_item(item, idx);
-	if (!old_known) auto_destroy_item(item, idx);
+	autopick_alter_item(item, (bool)(destroy_identify && !old_known));
 
 	return (TRUE);
 }
@@ -490,6 +487,39 @@ static bool cmd_racial_power_aux(s32b command)
 					(void)detect_objects_magic(DETECT_RAD_DEFAULT);
 				}
 				break;
+			case CLASS_ELEMENTALIST:
+				switch(p_ptr->realm1)
+				{
+				case 0:
+					(void)lite_area(damroll(2, (plev / 2)), (plev / 10) + 1);
+					break;
+				case 1:
+					if (!get_aim_dir(&dir)) return FALSE;
+					(void)project_hook(GF_OLD_SLEEP, dir, (p_ptr->lev * 2),
+						PROJECT_STOP | PROJECT_KILL | PROJECT_REFLECTABLE);
+					break;
+				case 2:
+					(void)recharge(120);
+					break;
+				case 3:
+					if (!get_aim_dir(&dir)) return FALSE;
+					(void)wall_to_mud(dir);
+					break;
+				case 4:
+					if (!get_aim_dir(&dir)) return FALSE;
+					control_one_undead(dir, p_ptr->lev * 3 / 2);
+					break;
+				case 5:
+					(void)alter_reality();
+					break;
+				case 6:
+					(void)earthquake(py, px, 10);
+					break;
+				case 7:
+					(void)dispel_monsters(p_ptr->lev / 2);
+					break;
+				}
+				break;
 		}
 	}
 	else switch (p_ptr->prace)
@@ -860,7 +890,7 @@ static bool cmd_racial_power_aux(s32b command)
 
 		case RACE_VAMPIRE:
 			{
-				int y, x, dummy = 0;
+				int y, x, dummy;
 				cave_type *c_ptr;
 
 				/* Only works on adjacent monsters */
@@ -1054,6 +1084,107 @@ void do_cmd_racial_power(void)
 			power_desc[num].fail = 15;
 			power_desc[num++].number = -4;
 			break;
+		case CLASS_ELEMENTALIST:
+			switch(p_ptr->realm1)
+			{
+			case 0:	/* Fire */
+#ifdef JP
+				strcpy(power_desc[num].name, "饤ȡꥢ");
+#else
+				strcpy(power_desc[num].name, "Light area");
+#endif
+				power_desc[num].level = 3;
+				power_desc[num].cost = 5;
+				power_desc[num].stat = A_INT;
+				power_desc[num].fail = 10;
+				power_desc[num++].number = -3;
+				break;
+			case 1:	/* Cold */
+#ifdef JP
+				strcpy(power_desc[num].name, "ե꡼󥹥");
+#else
+				strcpy(power_desc[num].name, "Sleep monster");
+#endif
+				power_desc[num].level = 10;
+				power_desc[num].cost = 10;
+				power_desc[num].stat = A_INT;
+				power_desc[num].fail = 15;
+				power_desc[num++].number = -3;
+				break;
+			case 2:	/* Elec */
+#ifdef JP
+				strcpy(power_desc[num].name, "ϽŶ");
+#else
+				strcpy(power_desc[num].name, "Recharging");
+#endif
+				power_desc[num].level = 20;
+				power_desc[num].cost = 15;
+				power_desc[num].stat = A_INT;
+				power_desc[num].fail = 25;
+				power_desc[num++].number = -3;
+				break;
+			case 3:	/* Acid */
+#ifdef JP
+				strcpy(power_desc[num].name, "ϲ");
+#else
+				strcpy(power_desc[num].name, "Stone to mud");
+#endif
+				power_desc[num].level = 5;
+				power_desc[num].cost = 5;
+				power_desc[num].stat = A_INT;
+				power_desc[num].fail = 10;
+				power_desc[num++].number = -3;
+				break;
+			case 4:	/* Dark */
+#ifdef JP
+				strcpy(power_desc[num].name, "ǥåɽ°");
+#else
+				strcpy(power_desc[num].name, "Enslave undead");
+#endif
+				power_desc[num].level = 10;
+				power_desc[num].cost = 10;
+				power_desc[num].stat = A_INT;
+				power_desc[num].fail = 20;
+				power_desc[num++].number = -3;
+				break;
+			case 5:	/* Conf */
+#ifdef JP
+				strcpy(power_desc[num].name, "");
+#else
+				strcpy(power_desc[num].name, "Alter reality");
+#endif
+				power_desc[num].level = 35;
+				power_desc[num].cost = 30;
+				power_desc[num].stat = A_INT;
+				power_desc[num].fail = 40;
+				power_desc[num++].number = -3;
+				break;
+			case 6:	/* Shar */
+#ifdef JP
+				strcpy(power_desc[num].name, "Ͽ");
+#else
+				strcpy(power_desc[num].name, "Earthquake");
+#endif
+				power_desc[num].level = 25;
+				power_desc[num].cost = 15;
+				power_desc[num].stat = A_INT;
+				power_desc[num].fail = 20;
+				power_desc[num++].number = -3;
+				break;
+			case 7:	/* Pois */
+#ifdef JP
+				strcpy(power_desc[num].name, "");
+#else
+				strcpy(power_desc[num].name, "Pesticide");
+#endif
+				power_desc[num].level = 5;
+				power_desc[num].cost = 3;
+				power_desc[num].stat = A_INT;
+				power_desc[num].fail = 20;
+				power_desc[num++].number = -3;
+				break;
+			}
+			break;
 		default:
 #ifdef JP
 			strcpy(power_desc[num].name, "(ʤ)");
@@ -1308,7 +1439,7 @@ void do_cmd_racial_power(void)
 		case RACE_SKELETON:
 		case RACE_ZOMBIE:
 #ifdef JP
-			strcpy(power_desc[num].name, "̿");
+			strcpy(power_desc[num].name, "и");
 #else
 			strcpy(power_desc[num].name, "restore life");
 #endif
@@ -1346,7 +1477,11 @@ void do_cmd_racial_power(void)
 			break;
 	}
 
+#if 0
 	if ((num == 0) && !p_ptr->muta)
+#else
+	if (num == 0)
+#endif
 	{
 #ifdef JP
 		msg_print("ȤüǽϤ⤢ޤ");
