@@ -4640,7 +4640,7 @@ msg_print("ʪޤʤä");
 #endif
 
 		if (ironman_hengband)
-			p_ptr->energy_need += (s16b)((s32b)(60 - plev) * ENERGY_NEED() / 100L);
+			p_ptr->energy_need += ENERGY_NEED();
 		else
 			p_ptr->energy_need += 100;
 		teleport_player(10);
