@@ -62,16 +62,13 @@ struct feature_type
 
 	byte mimic;			/* Feature to mimic */
 
-	byte extra;			/* Extra byte (unused) */
+	u16b priority;            /* Map priority */
 
-	s16b unused;		/* Extra bytes (unused) */
+	byte d_attr[F_LIT_MAX];   /* Default feature attribute */
+	char d_char[F_LIT_MAX];   /* Default feature character */
 
-	byte d_attr;		/* Default feature attribute */
-	char d_char;		/* Default feature character */
-
-
-	byte x_attr;		/* Desired feature attribute */
-	char x_char;		/* Desired feature character */
+	byte x_attr[F_LIT_MAX];   /* Desired feature attribute */
+	char x_char[F_LIT_MAX];   /* Desired feature character */
 };
 
 
@@ -87,6 +84,7 @@ struct object_kind
 {
 	u32b name;			/* Name (offset) */
 	u32b text;			/* Text (offset) */
+	u32b flavor_name;	/* Flavor name (offset) */
 
 	byte tval;			/* Object type */
 	byte sval;			/* Object sub type */
@@ -126,7 +124,7 @@ struct object_kind
 	char x_char;		/* Desired object character */
 
 
-	byte flavor;			/* Special object flavor (or zero) */
+	s16b flavor;		/* Special object flavor (or zero) */
 
 	bool easy_know;		/* This object is always known (if aware) */
 
@@ -836,7 +834,7 @@ struct player_race
 	byte infra;			/* Infra-vision	range */
 
 	u16b choice;        /* Legal class choices */
-	byte can_birth;		/* Allow this race as charactor race */
+	bool can_birth;		/* Allow this race as charactor race */
 /*    byte choice_xtra;   */
 };
 
@@ -1167,6 +1165,10 @@ struct player_type
 	s16b pspeed;		/* Current speed */
 
 	bool dtrap;
+	bool autopick_autoregister; /* auto register is in-use or not */
+
+	byte feeling;		/* Most recent dungeon feeling */
+	s32b feeling_turn;	/* The turn of the last dungeon feeling */
 
 	/*** Pet commands ***/
 	s16b pet_follow_distance; /* Length of the imaginary "leash" for pets */
@@ -1175,7 +1177,6 @@ struct player_type
 
 	/*** Temporary fields ***/
 	byte exit_bldg;			/* Goal obtained in arena? -KMW- */
-	byte leftbldg;			/* did we just leave a special area? -KMW- */
 	bool leaving;			/* True if player is leaving */
 
 	bool leaving_dungeon;	/* True if player is leaving the dungeon */
