@@ -45,9 +45,9 @@ int level_up = 0;
 /* 
  *  List for auto-picker/destroyer entries
  */
-int max_autopick=0;
-autopick_type autopick_list[MAX_AUTOPICK];
-autopick_type autopick_entry_last_destroyed;
+int max_autopick = 0;
+int max_max_autopick = 0;
+autopick_type *autopick_list = NULL;
 
 /*
  * Executable version
@@ -143,7 +143,7 @@ s16b monster_level;		/* Current monster creation level */
 s16b base_level;        /* Base dungeon level */
 
 s32b turn;				/* Current game turn */
-s32b old_turn;			/* Turn when level began (feelings) */
+s32b old_turn;			/* Turn when level began */
 
 bool wizard;			/* Is the player currently in Wizard mode? */
 
@@ -162,7 +162,6 @@ bool inkey_base;		/* See the "inkey()" function */
 bool inkey_xtra;		/* See the "inkey()" function */
 bool inkey_scan;		/* See the "inkey()" function */
 bool inkey_flag;		/* See the "inkey()" function */
-bool inkey_special;		/* See the "inkey()" function */
 
 s16b coin_type;			/* Hack -- force coin type */
 
@@ -371,11 +370,6 @@ s16b autosave_freq;     /* Autosave frequency */
  * Dungeon variables
  */
 
-byte feeling;			/* Most recent feeling */
-s16b rating;			/* Level's current rating */
-
-bool good_item_flag;		/* True if "Artifact" on this level */
-
 bool closing_flag;		/* Dungeon is closing */
 
 
@@ -1010,9 +1004,11 @@ bool easy_floor;
 #endif /* ALLOW_EASY_FLOOR -- TNB */
 
 bool use_command;
+bool numpad_as_cursorkey;	/* Use numpad keys as cursor key in editor mode */
 bool center_player;
 bool avoid_center;
-bool pillar_tunnels;
+bool abbrev_extra;	/* Describe obj's extra resistances by abbreviation */
+bool abbrev_all;	/* Describe obj's all resistances by abbreviation */
 bool exp_need;
 
 /* Auto-destruction options */
@@ -1148,7 +1144,7 @@ bool fast_autoroller;
 
 bool use_transparency = FALSE; /* Use transparent tiles */
 
-bool can_save = TRUE;         /* Game can be saved */
+bool can_save = FALSE;         /* Game can be saved */
 u32b playtime;			/* Total playtime */
 u32b start_time;		/* Start time of Game */
 
