@@ -154,8 +154,8 @@ static uint vstrnfmt_aux_dflt(char *buf, uint max, cptr fmt, vptr arg)
 	uint len;
 	char tmp[32];
 
-	/* XXX XXX */
-	fmt = fmt ? fmt : 0;
+	/* Unused */
+	(void)fmt;
 
 	/* Pointer display */
 	sprintf(tmp, "<<%p>>", arg);
